@@ -1,5 +1,5 @@
-from .reactor import Reactor
 from .shape import Shape
+from .reactor import Reactor
 
 from .parametric_shapes.extruded_spline_shape import ExtrudeSplineShape
 from .parametric_shapes.extruded_straight_shape import ExtrudeStraightShape
@@ -14,22 +14,46 @@ from .parametric_shapes.rotate_circle_shape import RotateCircleShape
 
 from .parametric_components.tokamak_plasma import Plasma
 
-from .parametric_components.blanket_constant_width import BlanketConstantThickness
-from .parametric_components.blanket_constant_width import ConstantThicknessArcV
+from .parametric_components.blanket_constant_thickness_arc_h import (
+    BlanketConstantThicknessArcH,
+)
+from .parametric_components.blanket_constant_thickness_arc_v import (
+    BlanketConstantThicknessArcV,
+)
+from .parametric_components.blanket_constant_thickness_fp import (
+    BlanketConstantThicknessFP,
+)
 
 from .parametric_components.divertor_block import DivertorBlock
 
 from .parametric_components.center_column_cylinder import CenterColumnShieldCylinder
 from .parametric_components.center_column_hyperbola import CenterColumnShieldHyperbola
-from .parametric_components.center_column_flat_top_hyperbola import CenterColumnShieldFlatTopHyperbola
-from .parametric_components.center_column_plasma_dependant import CenterColumnShieldPlasmaHyperbola
+from .parametric_components.center_column_flat_top_hyperbola import (
+    CenterColumnShieldFlatTopHyperbola,
+)
+from .parametric_components.center_column_plasma_dependant import (
+    CenterColumnShieldPlasmaHyperbola,
+)
 
 from .parametric_components.center_column_circular import CenterColumnShieldCircular
-from .parametric_components.center_column_flat_top_circular import CenterColumnShieldFlatTopCircular
+from .parametric_components.center_column_flat_top_circular import (
+    CenterColumnShieldFlatTopCircular,
+)
 
 from .parametric_components.poloidal_field_coil import PoloidalFieldCoil
 from .parametric_components.poloidal_field_coil_case import PoloidalFieldCoilCase
-from .parametric_components.poloidal_field_coil_case import PoloidalFieldCoilCaseFromCoil
+from .parametric_components.poloidal_field_coil_case_fc import PoloidalFieldCoilCaseFC
 
 from .parametric_components.inner_tf_coils_circular import InnerTfCoilsCircular
 from .parametric_components.inner_tf_coils_flat import InnerTfCoilsFlat
+
+
+from .parametric_reactors.ball_reactor import BallReactor
+from .parametric_reactors.submersion_ball_reactor import SubmersionBallReactor
+
+from .parametric_components.toroidal_field_coil_coat_hanger import (
+    ToroidalFieldCoilCoatHanger,
+)
+from .parametric_components.toroidal_field_coil_rectangle import (
+    ToroidalFieldCoilRectangle,
+)
