@@ -1,7 +1,10 @@
-
 from paramak import RotateMixedShape
 
+
 class CenterColumnShieldFlatTopCircular(RotateMixedShape):
+    """A center column shield volume with a circular outer profile joined to flat profiles
+    at the top and bottom of the shield, and a constant cylindrical inner profile.
+    """
 
     def __init__(
         self,
@@ -108,4 +111,4 @@ class CenterColumnShieldFlatTopCircular(RotateMixedShape):
             (self.inner_radius, 0, "straight"),
         ]
 
-        self.points = points
\ No newline at end of file
+        self.points = points
