@@ -1,4 +1,3 @@
-
 from collections import Iterable
 
 import cadquery as cq
@@ -101,15 +100,16 @@ class RotateMixedShape(Shape):
 
     def get_hash(self):
         hash_object = blake2b()
-        hash_object.update(str(self.points).encode('utf-8') +
-                           str(self.workplane).encode('utf-8') +
-                           str(self.name).encode('utf-8') +
-                           str(self.color).encode('utf-8') +
-                           str(self.material_tag).encode('utf-8') +
-                           str(self.stp_filename).encode('utf-8') +
-                           str(self.azimuth_placement_angle).encode('utf-8') +
-                           str(self.rotation_angle).encode('utf-8') +
-                           str(self.cut).encode('utf-8')
+        hash_object.update(
+            str(self.points).encode("utf-8")
+            + str(self.workplane).encode("utf-8")
+            + str(self.name).encode("utf-8")
+            + str(self.color).encode("utf-8")
+            + str(self.material_tag).encode("utf-8")
+            + str(self.stp_filename).encode("utf-8")
+            + str(self.azimuth_placement_angle).encode("utf-8")
+            + str(self.rotation_angle).encode("utf-8")
+            + str(self.cut).encode("utf-8")
         )
         value = hash_object.hexdigest()
         return value
@@ -162,7 +162,7 @@ class RotateMixedShape(Shape):
                 p0 = list(entry.values())[0][0]
                 p1 = list(entry.values())[0][1]
                 p2 = list(entry.values())[0][2]
-                solid = solid.moveTo(p0[0],p0[1]).threePointArc(p1, p2)
+                solid = solid.moveTo(p0[0], p0[1]).threePointArc(p1, p2)
 
         solid = solid.close().revolve(self.rotation_angle)
 
