@@ -1,4 +1,3 @@
-
 import json
 import math
 from collections import Iterable
@@ -13,7 +12,9 @@ from PIL import Image
 
 from paramak.shape import Shape
 
-class Reactor(list):
+
+class Reactor():
+
     """The Reactor object allows Shapes to be added and then collective 
     opperations to be performed on all the Shapes within the Reactor.
     Combining all the shapes is required for creating images of the whole reactor and 
@@ -23,16 +24,46 @@ class Reactor(list):
     def __init__(self):
 
         self.graveyard = None
+        self.shapes_and_components = []
+        self.material_tags = []
+        self.stp_filenames = []
+        self.solid = None
 
-    def add_shape(self, shapes):
-        """Adds a Shape or list of Shapes to the Reactor object so that
-        collective operations can be performed on all the shapes in the reactor.
+    def add_shape_or_component(self, shapes):
+        """Adds a parametric shape(s) or a parametric component(s) to the Reactor 
+        object. An individual shape/component or a list of shapes/ components are
+        added to the Reactor object so that collective operations can be performed
+        on all the shapes in the reactor. When adding a shape or componet the 
+        stp_filename for the shape or compnent should not already be used in the 
+        reactor.
         """
         if isinstance(shapes, Iterable):
             for shape in shapes:
-                self.append(shape)
+                if shape.material_tag != None:
+                    self.material_tags.append(shape.material_tag)
+                if shape.stp_filename != None:
+                    if shape.stp_filename in self.stp_filenames:
+                        raise ValueError(
+                            "Set Reactor already contains a shape or component \
+                                 with this stp_filename"
+                        )
+                    else:
+                        self.stp_filenames.append(shape.stp_filename)
+                self.shapes_and_components.append(shape)
         else:
-            self.append(shapes)
+            if shapes.material_tag != None:
+                self.material_tags.append(shapes.material_tag)
+            if shapes.stp_filename != None:
+                if shapes.stp_filename in self.stp_filenames:
+                    raise ValueError(
+                        "Set Reactor already contains a shape or component \
+                                with this stp_filename"
+                    )
+                else:
+                    self.stp_filenames.append(shapes.stp_filename)
+            self.shapes_and_components.append(shapes)
+        
+        self.solid = cq.Compound.makeCompound([a.solid.val() for a in self.shapes_and_components])
 
     def neutronics_description(self):
         """A descirption of the reactor containing materials and the filenames,
@@ -44,7 +75,7 @@ class Reactor(list):
 
         neutronics_description = []
 
-        for entry in self:
+        for entry in self.shapes_and_components:
 
             if entry.stp_filename is None:
                 raise ValueError(
@@ -112,7 +143,7 @@ class Reactor(list):
         """
 
         filenames = []
-        for entry in self:
+        for entry in self.shapes_and_components:
             if entry.stp_filename is None:
                 raise ValueError(
                     "set .stp_filename property for \
@@ -138,7 +169,7 @@ class Reactor(list):
 
         :param filename: the filename for saving the stp file to
         :type filename: str
-        ...
+
         :return: the stp filename created
         :rtype: str
         """
@@ -155,13 +186,13 @@ class Reactor(list):
         :rtype: CadQuery solid
         """
 
-        for component in self:
+        for component in self.shapes_and_components:
             if component.solid is None:
                 component.create_solid()
 
         # finds the largest dimenton in all the Shapes that are in the reactor
         largest_dimension = 0
-        for component in self:
+        for component in self.shapes_and_components:
             if component.solid.largestDimension() > largest_dimension:
                 largest_dimension = component.solid.largestDimension()
 
@@ -212,7 +243,7 @@ class Reactor(list):
         fig, ax = plt.subplots()
 
         # creates indvidual patches for each Shape which are combined together
-        for entry in self:
+        for entry in self.shapes_and_components:
             p = entry._create_patch()
             ax.add_collection(p)
 
@@ -241,7 +272,7 @@ class Reactor(list):
         """
 
         scene = pyrender.Scene(ambient_light=np.array([0.1, 0.1, 0.1, 1.0]))
-        for entry in self:
+        for entry in self.shapes_and_components:
             if entry.render_mesh is None:
                 scene.add(entry._create_render_mesh(tolerance))
 
@@ -300,7 +331,7 @@ class Reactor(list):
         )
 
         # accesses the Shape traces for each Shape and adds them to the figure
-        for entry in self:
+        for entry in self.shapes_and_components:
             fig.add_trace(entry._trace())
 
         fig.write_html(str(Pfilename))
