@@ -1,4 +1,3 @@
-
 import math
 import numbers
 from pathlib import Path
@@ -189,11 +188,14 @@ class Shape:
             if not all(len(entry) == 2 for entry in values):
                 if not all(len(entry) == 3 for entry in values):
                     raise ValueError(
-                        "The points list should contain entries of length 2 or 3 but not a mixture of 2 and 3")
+                        "The points list should contain entries of length 2 or 3 but not a mixture of 2 and 3"
+                    )
 
             if len(values) > 1:
                 if values[-1][0] == values[0][0] and values[-1][1] == values[0][1]:
-                    raise ValueError("The coordinates of the last and first points are the same.")
+                    raise ValueError(
+                        "The coordinates of the last and first points are the same."
+                    )
                 else:
                     values.append(values[0])
 
@@ -297,23 +299,29 @@ class Shape:
 
         return str(Pfilename)
 
-    def export_stp(self, filename):
+    def export_stp(self, filename=None):
         """Exports an stp file for the Shape.solid.
         If the provided filename doesn't end with
-        .stp or .step then .stp will be added
+        .stp or .step then .stp will be added. If a
+        filename is not provided and the shapes 
+        stp_filename property is not None the stp_filename
+        will be used as the export filename
 
         :param filename: the filename of the stp
         :type filename: str
         """
 
-        Pfilename = Path(filename)
+        if filename != None:
+            Pfilename = Path(filename)
 
-        if Pfilename.suffix == ".stp" or Pfilename.suffix == ".step":
-            pass
-        else:
-            Pfilename = Pfilename.with_suffix(".stp")
+            if Pfilename.suffix == ".stp" or Pfilename.suffix == ".step":
+                pass
+            else:
+                Pfilename = Pfilename.with_suffix(".stp")
 
-        Pfilename.parents[0].mkdir(parents=True, exist_ok=True)
+            Pfilename.parents[0].mkdir(parents=True, exist_ok=True)
+        elif self.stp_filename != None:
+            Pfilename = Path(self.stp_filename)
 
         with open(Pfilename, "w") as f:
             exporters.exportShape(self.solid, "STEP", f)
