@@ -80,7 +80,7 @@ class test_object_properties(unittest.TestCase):
         os.chdir(Path("examples/neutronics"))
         output_filename = "simulation_result.json"
         os.system("rm " + output_filename)
-        os.system("python make_simple_paramak_neutronics_model.py")
+        os.system("python make_simple_neutronics_model.py")
         with open(output_filename) as json_file:
             data = json.load(json_file)
         assert data['TBR'] == pytest.approx(0.456, abs=0.01)
